@@ -6,18 +6,17 @@ __url__ = "https://github.com/xor-cipher/xor-cipher"
 __title__ = "xor_cipher"
 __author__ = "nekitdev, RealistikDash"
 __license__ = "MIT"
-__version__ = "2.4.0"
+__version__ = "3.0.0"
 
 from xor_cipher.core import (
     DEFAULT_ENCODING,
     DEFAULT_ERRORS,
-    FAST,
     cyclic_xor,
     cyclic_xor_in_place,
     cyclic_xor_in_place_unsafe,
-    cyclic_xor_unsafe,
     cyclic_xor_string,
     cyclic_xor_string_unsafe,
+    cyclic_xor_unsafe,
     xor,
     xor_in_place,
     xor_string,
@@ -26,7 +25,6 @@ from xor_cipher.core import (
 __all__ = (
     "DEFAULT_ENCODING",
     "DEFAULT_ERRORS",
-    "FAST",
     "cyclic_xor",
     "cyclic_xor_in_place",
     "cyclic_xor_in_place_unsafe",
@@ -37,3 +35,17 @@ __all__ = (
     "xor_in_place",
     "xor_string",
 )
+
+
+try:
+    from xor_cipher.extension import (  # type: ignore
+        cyclic_xor,
+        cyclic_xor_in_place,
+        cyclic_xor_in_place_unsafe,
+        cyclic_xor_unsafe,
+        xor,
+        xor_in_place,
+    )
+
+except ImportError:
+    pass
